@@ -118,6 +118,11 @@ class Group(Expression):
     arg_types = {'this': True, 'expressions': True}
 
 
+class Limit(Expression):
+    token_type = TokenType.GROUP
+    arg_types = {'this': True, 'limit': True}
+
+
 class Join(Expression):
     token_type = TokenType.JOIN
     arg_types = {'this': True, 'expression': True, 'on': True, 'side': False, 'kind': False}
@@ -145,7 +150,7 @@ class Unnest(Expression):
 
 class Select(Expression):
     token_type = TokenType.SELECT
-    arg_types = {'expressions': True, 'hint': False}
+    arg_types = {'expressions': True, 'hint': False, 'distinct': False}
 
 
 class Window(Expression):
@@ -203,6 +208,10 @@ class LTE(Binary):
     token_type = TokenType.LTE
 
 
+class Mod(Binary):
+    token_type = TokenType.MOD
+
+
 class NEQ(Binary):
     token_type = TokenType.NEQ
 
