@@ -253,7 +253,12 @@ class Parser:
             return None
 
         hint = self._parse_hint()
-        this = exp.Select(expressions=self._parse_csv(self._parse_expression), hint=hint)
+        distinct = self._match(TokenType.DISTINCT)
+        this = exp.Select(
+            expressions=self._parse_csv(self._parse_expression),
+            hint=hint,
+            distinct=distinct,
+        )
         this = self._parse_from(this)
         this = self._parse_lateral(this)
         this = self._parse_join(this)
@@ -261,6 +266,7 @@ class Parser:
         this = self._parse_group(this)
         this = self._parse_having(this)
         this = self._parse_order(this)
+        this = self._parse_limit(this)
         this = self._parse_union(this)
         return this
 
@@ -408,6 +414,15 @@ class Parser:
 
         return exp.Order(this=this, expressions=self._parse_csv(self._parse_primary), desc=self._match(TokenType.DESC))
 
+    def _parse_limit(self, this):
+        if not self._match(TokenType.LIMIT):
+            return this
+
+        if not self._match(TokenType.NUMBER):
+            self.raise_error('Expected NUMBER after LIMIT')
+
+        return exp.Limit(this=this, limit=self._prev)
+
     def _parse_union(self, this):
         if not self._match(TokenType.UNION):
             return this
@@ -448,7 +463,7 @@ class Parser:
         return this
 
     def _parse_term(self):
-        return self._parse_tokens(self._parse_factor, exp.Minus, exp.Plus)
+        return self._parse_tokens(self._parse_factor, exp.Minus, exp.Plus, exp.Mod)
 
     def _parse_factor(self):
         return self._parse_tokens(self._parse_unary, exp.Slash, exp.Star)
